@@ -40,6 +40,7 @@ pub enum OperatorKind {
 	Mul,
 	Div,
 	Deref,
+	Equals,
 }
 
 impl OperatorKind {
@@ -64,6 +65,9 @@ impl OperatorKind {
 			"/" => {
 				OperatorKind::Div
 			}
+			"==" => {
+				OperatorKind::Equals
+			}
 			_ => {
 				OperatorKind::Unsupported
 			},
@@ -690,6 +694,9 @@ impl Element for Func<'_, '_> {
 							"try_deref_mut".into()
 						}
 					}
+					OperatorKind::Equals => {
+						"equals".into()
+					}
 				}
 			} else {
 				cpp_name
